@@ -401,10 +401,12 @@ class Playlist(GObject.GObject):
                 NOT EXISTS { ?song a nmm:Video }
                 && NOT EXISTS { ?song a nmm:Playlist }
             )
+            %(location_filter)s
         }
         ORDER BY nfo:listPosition(?entry)
         """.replace('\n', ' ').strip() % {
-            'filter_clause': 'tracker:id(?playlist) = ' + self.props.pl_id
+            "filter_clause": 'tracker:id(?playlist) = ' + self.props.pl_id,
+            "location_filter": self._tracker_wrapper.location_filter()
         }
 
         def _add_to_playlist_cb(
@@ -430,17 +432,23 @@ class Playlist(GObject.GObject):
     def _bind_to_main_song(self, coresong):
         main_coresong = self._songs_hash[coresong.props.media.get_id()]
 
-        properties = [
+        # It is not necessary to bind all the CoreSong properties:
+        # selected property is linked to a view
+        # validation is a short-lived playability check for local songs
+        bidirectional_properties = [
             "album", "album_disc_number", "artist", "duration", "media",
-            "grlid", "play_count", "state", "title", "track_number", "url",
-            "validation", "favorite", "selected"]
+            "grlid", "play_count", "title", "track_number", "url", "favorite"]
 
-        for prop in properties:
+        for prop in bidirectional_properties:
             main_coresong.bind_property(
                 prop, coresong, prop,
                 GObject.BindingFlags.BIDIRECTIONAL
                 | GObject.BindingFlags.SYNC_CREATE)
 
+        # There is no need for the "state" property to be bidirectional
+        coresong.bind_property(
+            prop, main_coresong, "state", GObject.BindingFlags.DEFAULT)
+
     @GObject.Property(type=str, default=None)
     def title(self):
         """Playlist title
@@ -645,9 +653,13 @@ class Playlist(GObject.GObject):
                     NOT EXISTS { ?song a nmm:Video }
                     && NOT EXISTS { ?song a nmm:Playlist }
                 )
+                %(location_filter)s
             }
             """.replace("\n", " ").strip() % {
-                "filter_clause": "tracker:id(?song) = " + media_id}
+                "filter_clause": "tracker:id(?song) = " + media_id,
+                "location_filter": self._tracker_wrapper.location_filter()
+            }
+
             options = self._fast_options.copy()
             self._source.query(
                 query, self.METADATA_KEYS, options, _add_to_model)
@@ -788,6 +800,7 @@ class SmartPlaylist(Playlist):
     def _finish_update(self, new_model_medias):
         if not new_model_medias:
             self._model.remove_all()
+            self.props.count = 0
             return
 
         current_models_ids = [coresong.props.media.get_id()
