@@ -27,7 +27,6 @@ from enum import IntEnum
 from gettext import gettext as _, ngettext
 from gi.repository import GObject, Gtk
 
-from gnomemusic import log
 from gnomemusic.widgets.appmenu import AppMenu
 
 
@@ -42,9 +41,6 @@ class SelectionBarMenuButton(Gtk.MenuButton):
 
     _menu_label = Gtk.Template.Child()
 
-    def __repr__(self):
-        return "<SelectionBarMenuButton>"
-
     def __init__(self):
         super().__init__()
 
@@ -103,11 +99,11 @@ class HeaderBar(Gtk.HeaderBar):
     selection_mode_allowed = GObject.Property(type=bool, default=True)
     stack = GObject.Property(type=Gtk.Stack)
 
-    def __repr__(self):
-        return "<HeaderBar>"
+    def __init__(self, application):
+        """Initialize Headerbar
 
-    @log
-    def __init__(self):
+        :param Application application: Application object
+        """
         super().__init__()
 
         self._selection_mode = False
@@ -118,7 +114,7 @@ class HeaderBar(Gtk.HeaderBar):
 
         self._selection_menu = SelectionBarMenuButton()
 
-        self._menu_button.set_popover(AppMenu())
+        self._menu_button.set_popover(AppMenu(application))
 
         self.bind_property(
             "selection-mode", self, "show-close-button",
@@ -206,16 +202,13 @@ class HeaderBar(Gtk.HeaderBar):
             self._stack_switcher.show()
 
     @Gtk.Template.Callback()
-    @log
     def _on_back_button_clicked(self, widget=None):
         self.emit('back-button-clicked')
 
     @Gtk.Template.Callback()
-    @log
     def _on_cancel_button_clicked(self, button):
         self.props.selection_mode = False
 
-    @log
     def _update(self):
         if self.props.selection_mode:
             self.props.custom_title = self._selection_menu
@@ -235,7 +228,6 @@ class HeaderBar(Gtk.HeaderBar):
             and self.props.state == HeaderBar.State.MAIN
         )
 
-    @log
     def _on_selection_mode_allowed_changed(self, widget, data):
         if self.props.selection_mode_allowed:
             self._select_button.props.sensitive = True
